summaryrefslogtreecommitdiffstats
path: root/kopete/libkopete/kopeteblacklister.h
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/libkopete/kopeteblacklister.h')
-rw-r--r--kopete/libkopete/kopeteblacklister.h7
1 files changed, 4 insertions, 3 deletions
diff --git a/kopete/libkopete/kopeteblacklister.h b/kopete/libkopete/kopeteblacklister.h
index c2df1bca..d5c946fe 100644
--- a/kopete/libkopete/kopeteblacklister.h
+++ b/kopete/libkopete/kopeteblacklister.h
@@ -42,19 +42,20 @@ class Contact;
*
* @author Roie Kerstein <sf_kersteinroie@bezeqint.net>
*/
-class BlackLister : public QObject
+class BlackLister : public TQObject
{
Q_OBJECT
+ TQ_OBJECT
public:
/**
* Create an instance, and read the blacklist from disk if it exists.
* @param protocolId is the ID of the protocol owning accountId
* @param accountId is the ID of the owning Account.
* @param parent The TQObject parent for this class.
* @param name The TQObject name for this class.
*/
- BlackLister( const TQString &protocolId, const TQString &accountId, TQObject *parent = 0, const char *name = 0 );
+ BlackLister( const TQString &protocolId, const TQString &accountId, TQObject *tqparent = 0, const char *name = 0 );
~BlackLister();
/**
@@ -42,19 +42,20 @@ class Contact;
* @param protocolId is the ID of the protocol owning accountId
* @param accountId is the ID of the owning Account.
- * @param parent The TQObject parent for this class.
+ * @param tqparent The TQObject tqparent for this class.
* @param name The TQObject name for this class.
*/